from setuptools import setup

setup(
    name='DA-demo-module',
    version='0.1.0',    
    description='A example Python package',
    author='D-Korobkov',
    author_email='email@email.com',
    url='https://colab.research.google.com/drive/1e42VW-f5vJM1BxK_Fw2kh1sjJfSV1vGs#scrollTo=loose-emerald',
    packages=['DA-demo-module'],
    install_requires=['numpy==1.20.3'],

    classifiers=['Programming Language :: Python :: 3.6'],
)